@@ -21,13 +21,14 @@
 #' 
 
 update_db <- function(connect, end = Sys.Date() - 1, ...) {
-  if (!require('DBI')) warning("The DBI package is required to use this function.\n",
+  if (!requireNamespace('DBI')) warning("The DBI package is required to use this function.\n",
                                "Please run install.packages('DBI')")
-  if(!dbExistsTable(connect, "atbat")) stop("Your database must have the atbat table in order to work")
+  if(!DBI::dbExistsTable(connect, "atbat")) stop("Your database must have the atbat table in order to work")
   # Create an index for faster querying
   # Note this throws an error if the INDEX already exists
-  res <- plyr::try_default(dbSendQuery(connect, 'CREATE INDEX gid_idx ON atbat(gameday_link)'), NULL, quiet = TRUE)
-  old.gids <- dbGetQuery(connect, "SELECT DISTINCT gameday_link FROM atbat")[,1]
+  res <- plyr::try_default(DBI::dbSendQuery(connect, 'CREATE INDEX gid_idx ON atbat(gameday_link)'), NULL, quiet = TRUE)
+  old.gids <- DBI::dbGetQuery(connect, "SELECT DISTINCT gameday_link FROM atbat")[,1]
+  gids = NULL
   data(gids, package = "pitchRx", envir = environment())
   # new.gids are bound to obtain old games that didn't have a inning_all.xml file
   new.gids <- gids[!gids %in% old.gids]
@@ -36,7 +37,7 @@ update_db <- function(connect, end = Sys.Date() - 1, ...) {
   valid.gids <- new.gids[max(old.dates) + 1 <= new.dates & new.dates <= end]
   if (length(valid.gids) < 1) { message("Already up to date"); return(NULL) }
   # Figure out what suffices to pass along scrape
-  tbls <- dbListTables(connect)
+  tbls <- DBI::dbListTables(connect)
   suffices <- NULL
   inning_all.tbls <- c("action", "atbat", "pitch", "po", "runner")
   if (any(inning_all.tbls %in% tbls)) suffices <- c(suffices, "inning/inning_all.xml")
